/*
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */
package com.ibm.j9ddr.vm29.structure;

/**
 * Structure: _MINIDUMP_CALLBACK_OUTPUT
 *
 * This stub class represents a class that can return in memory offsets
 * to VM C and C++ structures.
 *
 * This particular implementation exists only to allow StructurePointer code to
 * compile at development time.  This is never loaded at run time.
 *
 * At runtime generated byte codes returning actual offset values from the core file
 * will be loaded by the StructureClassLoader.
 */
public final class _MINIDUMP_CALLBACK_OUTPUT {

	// VM Constants

	public static final long SIZEOF;

	// Offsets

	public static final int _CancelOffset_;
	public static final int _CheckCancelOffset_;
	public static final int _ContinueOffset_;
	public static final int _HandleOffset_;
	public static final int _MemoryBaseOffset_;
	public static final int _MemorySizeOffset_;
	public static final int _ModuleWriteFlagsOffset_;
	public static final int _SecondaryFlagsOffset_;
	public static final int _StatusOffset_;
	public static final int _ThreadWriteFlagsOffset_;
	public static final int _VmQueryResultOffset_;
	public static final int _VmQueryStatusOffset_;
	public static final int _VmReadBytesCompletedOffset_;
	public static final int _VmReadStatusOffset_;
	public static final int _VmRegionOffset_;

	// Static Initializer

	private static final boolean RUNTIME = false;

	static {
		if (!RUNTIME) {
			throw new IllegalArgumentException("This stub class should not be on your classpath");
		}

		SIZEOF = 0;
		_CancelOffset_ = 0;
		_CheckCancelOffset_ = 0;
		_ContinueOffset_ = 0;
		_HandleOffset_ = 0;
		_MemoryBaseOffset_ = 0;
		_MemorySizeOffset_ = 0;
		_ModuleWriteFlagsOffset_ = 0;
		_SecondaryFlagsOffset_ = 0;
		_StatusOffset_ = 0;
		_ThreadWriteFlagsOffset_ = 0;
		_VmQueryResultOffset_ = 0;
		_VmQueryStatusOffset_ = 0;
		_VmReadBytesCompletedOffset_ = 0;
		_VmReadStatusOffset_ = 0;
		_VmRegionOffset_ = 0;
	}

}
